@@ -58,6 +58,18 @@ class RpcConsumer(DependencyProvider, ProviderCollector):
             self.queue_consumer.register_provider(self)
             self._registered = True
 
+    def stop(self):
+        """ Stop the RpcConsumer.
+
+        The RpcConsumer ordinary unregisters from the QueueConsumer when the
+        last RpcProvider unregisters from it. If no providers were registered,
+        we should unregister ourself from the QueueConsumer as soon as we're
+        asked to stop.
+        """
+        if not self._providers_registered:
+            self.queue_consumer.unregister_provider(self)
+            self._unregistered_from_queue_consumer.send(True)
+
     def unregister_provider(self, provider):
         """ Unregister a provider.
 
